==> af-common-socket-2.9.33-sources.jar: com/af/v4/system/common/socket/core/server/mqtt/MqttServer.java <==
package com.af.v4.system.common.socket.core.server.mqtt;

import com.af.v4.system.common.core.enums.OSType;
import com.af.v4.system.common.core.service.ApplicationService;
import com.af.v4.system.common.socket.config.SocketConfigItem;
import com.af.v4.system.common.socket.core.channel.impl.MqttServerChannelHandler;
import com.af.v4.system.common.socket.core.server.SocketServer;
import io.netty.bootstrap.AbstractBootstrap;
import io.netty.bootstrap.ServerBootstrap;
import io.netty.channel.ChannelInitializer;
import io.netty.channel.ChannelOption;
import io.netty.channel.EventLoopGroup;
import io.netty.channel.ServerChannel;
import io.netty.channel.epoll.EpollEventLoopGroup;
import io.netty.channel.epoll.EpollServerSocketChannel;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.ServerSocketChannel;
import io.netty.channel.socket.SocketChannel;
import io.netty.channel.socket.nio.NioServerSocketChannel;
import io.netty.handler.codec.mqtt.MqttDecoder;
import io.netty.handler.codec.mqtt.MqttEncoder;
import jakarta.annotation.PreDestroy;

public class MqttServer extends SocketServer<ServerBootstrap, ServerChannel> {
    private static final int MAX_INCOMING_MESSAGE_SIZE = 1024 * 1024; // 设置最大消息大小为 1MB
    private final SocketConfigItem configItem;
    private EventLoopGroup bossGroup;
    private EventLoopGroup workerGroup;

    public MqttServer(SocketConfigItem configItem) {
        this.configItem = configItem;
    }

    @Override
    protected AbstractBootstrap<ServerBootstrap, ServerChannel> initBootstrap() {
        Class<? extends ServerSocketChannel> channelClass;
        if (ApplicationService.getOSType() == OSType.LINUX) {
            bossGroup = new EpollEventLoopGroup();
            workerGroup = new EpollEventLoopGroup();
            channelClass = EpollServerSocketChannel.class;
        } else {
            bossGroup = new NioEventLoopGroup();
            workerGroup = new NioEventLoopGroup();
            channelClass = NioServerSocketChannel.class;
        }
        try {
            // 配置 编码器、解码器、业务处理
            // tcp缓冲区
            // 将网络数据积累到一定的数量后,服务器端才发送出去,会造成一定的延迟。希望服务是低延迟的,建议将TCP_NODELAY设置为true
            // 保持长连接
            return new ServerBootstrap()
                    .group(bossGroup, workerGroup)
                    .channel(channelClass)
                    // 配置 编码器、解码器、业务处理
                    .childHandler(new ChannelInitializer<SocketChannel>() {
                        @Override
                        protected void initChannel(SocketChannel ch) {
                            ch.pipeline()
                                    .addLast("encoder", MqttEncoder.INSTANCE)
                                    .addLast("decoder", new MqttDecoder(MAX_INCOMING_MESSAGE_SIZE))
                                    .addLast(new MqttServerChannelHandler(configItem));
                        }
                    })
                    // tcp缓冲区
                    .option(ChannelOption.SO_BACKLOG, 128)
                    // 将网络数据积累到一定的数量后,服务器端才发送出去,会造成一定的延迟。希望服务是低延迟的,建议将TCP_NODELAY设置为true
                    .childOption(ChannelOption.TCP_NODELAY, true)
                    // 保持长连接
                    .childOption(ChannelOption.SO_KEEPALIVE, false);
        } catch (Exception e) {
            LOGGER.error("MqttServer initBootstrap error", e);
            destroy();
            return null;
        }
    }

    /**
     * 销毁
     */
    @PreDestroy
    @Override
    public void destroy() {
        bossGroup.shutdownGracefully();
        workerGroup.shutdownGracefully();
    }
}

==> af-common-socket-2.13.49-sources.jar: com/af/v4/system/common/socket/core/server/mqtt/MqttServer.java <==
package com.af.v4.system.common.socket.core.server.mqtt;

import com.af.v4.system.common.core.enums.OSType;
import com.af.v4.system.common.core.service.ApplicationService;
import com.af.v4.system.common.socket.SocketServerManager;
import com.af.v4.system.common.socket.config.SocketConfigItem;
import com.af.v4.system.common.socket.core.channel.impl.MqttServerChannelHandler;
import com.af.v4.system.common.socket.core.server.SocketServer;
import io.netty.bootstrap.AbstractBootstrap;
import io.netty.bootstrap.ServerBootstrap;
import io.netty.channel.ChannelInitializer;
import io.netty.channel.ChannelOption;
import io.netty.channel.EventLoopGroup;
import io.netty.channel.ServerChannel;
import io.netty.channel.epoll.EpollEventLoopGroup;
import io.netty.channel.epoll.EpollServerSocketChannel;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.ServerSocketChannel;
import io.netty.channel.socket.SocketChannel;
import io.netty.channel.socket.nio.NioServerSocketChannel;
import io.netty.handler.logging.LogLevel;
import io.netty.handler.logging.LoggingHandler;
import io.netty.handler.timeout.IdleStateHandler;
import io.netty.handler.codec.mqtt.MqttDecoder;
import io.netty.handler.codec.mqtt.MqttEncoder;
import jakarta.annotation.PreDestroy;

public class MqttServer extends SocketServer<ServerBootstrap, ServerChannel> {
    // 设置最大消息大小为 256KB
    private static final int MAX_INCOMING_MESSAGE_SIZE = 1024 * 256;
    private final SocketConfigItem configItem;
    private EventLoopGroup bossGroup;
    private EventLoopGroup workerGroup;

    public MqttServer(SocketConfigItem configItem) {
        this.configItem = configItem;
    }

    @Override
    protected AbstractBootstrap<ServerBootstrap, ServerChannel> initBootstrap() {
        Class<? extends ServerSocketChannel> channelClass;
        if (ApplicationService.getOSType() == OSType.LINUX) {
            bossGroup = new EpollEventLoopGroup();
            workerGroup = new EpollEventLoopGroup();
            channelClass = EpollServerSocketChannel.class;
        } else {
            bossGroup = new NioEventLoopGroup();
            workerGroup = new NioEventLoopGroup();
            channelClass = NioServerSocketChannel.class;
        }
        try {
            // 配置 编码器、解码器、业务处理
            // tcp缓冲区
            // 将网络数据积累到一定的数量后,服务器端才发送出去,会造成一定的延迟。希望服务是低延迟的,建议将TCP_NODELAY设置为true
            // 保持长连接
            return new ServerBootstrap()
                    .group(bossGroup, workerGroup)
                    .channel(channelClass)
                    .option(ChannelOption.SO_REUSEADDR, true)
                    // 配置 编码器、解码器、业务处理
                    .childHandler(new ChannelInitializer<SocketChannel>() {
                        @Override
                        protected void initChannel(SocketChannel ch) {
                            Integer idle = SocketServerManager.getConfigItemByChannel(ch).map(SocketConfigItem::getIdleSeconds).orElse(60);
                            Boolean debug = SocketServerManager.getConfigItemByChannel(ch).map(SocketConfigItem::getDebugLogging).orElse(false);
                            if (LOGGER.isDebugEnabled() || debug) {
                                ch.pipeline().addFirst(new LoggingHandler(LogLevel.DEBUG));
                            }
                            ch.pipeline()
                                    .addLast(new IdleStateHandler(0, 0, idle <= 0 ? 60 : idle))
                                    .addLast("encoder", MqttEncoder.INSTANCE)
                                    .addLast("decoder", new MqttDecoder(MAX_INCOMING_MESSAGE_SIZE))
                                    .addLast(new MqttServerChannelHandler(configItem));
                        }
                    })
                    // tcp缓冲区
                    .option(ChannelOption.SO_BACKLOG, 128)
                    // 将网络数据积累到一定的数量后,服务器端才发送出去,会造成一定的延迟。希望服务是低延迟的,建议将TCP_NODELAY设置为true
                    .childOption(ChannelOption.TCP_NODELAY, true)
                    // 保持长连接
                    .childOption(ChannelOption.SO_KEEPALIVE, false)
                    .childOption(ChannelOption.SO_REUSEADDR, true);
        } catch (Exception e) {
            LOGGER.error("MqttServer initBootstrap error", e);
            destroy();
            return null;
        }
    }

    /**
     * 销毁
     */
    @PreDestroy
    @Override
    public void destroy() {
        closeAllChannels();
        bossGroup.shutdownGracefully();
        workerGroup.shutdownGracefully();
    }
}
